@@ -1,9 +1,9 @@
 package String::PodQuote;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2019-12-16'; # DATE
+our $DATE = '2019-12-17'; # DATE
 our $DIST = 'String-PodQuote'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -13,7 +13,7 @@ use Exporter qw(import);
 our @EXPORT_OK = qw(pod_escape pod_quote);
 
 our %transforms = (
-    "<"  => "E<lt>",
+    ( map { ("$_<" => "${_}E<lt>") } 'A'..'Z' ),
     ">"  => "E<gt>",
     " "  => "E<32>",
     "\t" => "E<9>",
@@ -23,14 +23,9 @@ our %transforms = (
 );
 
 sub pod_escape {
-    my $opts = ref $_[0] eq 'HASH' ? shift : {};
     my $text = shift;
 
-    $text =~ s{
-                  ((?<=[A-Z])<|>|/|\||^[=\x09\x20])
-          }{
-              $transforms{$1}
-    }egmx;
+    $text =~ s{ ( [A-Z]< | [>/|] | ^[ \t=] ) }{$transforms{$1}}gmx;
     $text;
 }
 
@@ -52,7 +47,7 @@ String::PodQuote - Escape/quote special characters that might be interpreted by
 
 =head1 VERSION
 
-This document describes version 0.002 of String::PodQuote (from Perl distribution String-PodQuote), released on 2019-12-16.
+This document describes version 0.003 of String::PodQuote (from Perl distribution String-PodQuote), released on 2019-12-17.
 
 =head1 SYNOPSIS
 
@@ -76,7 +71,7 @@ Putting text inside a POD link:
 
 will output:
 
- L<Some description containing E<lt>, E<gt>, E<verbar>, E<sol>|Some::Module>
+ L<Some description containing <, E<gt>, E<verbar>, E<sol>|Some::Module>
 
 =head1 DESCRIPTION
 
